@@ -1989,7 +1989,7 @@ bool setbackuptime(crypt_t *pass,Connect *connect,int ind,uint32_t starttime) {
             uint32_t streamstart=
 #endif
             getinfo()->update[ind].streamstart=getbackuptimestream(starttime);
-            LOGGER("GLU: ind=%d %s streamstart=%d streamend=%d\n", ind,showsensorname().data(),streamstart,streamend);
+            LOGGER("GLU: from getbackuptimestream ind=%d %s streamstart=%d streamend=%d\n", ind,showsensorname().data(),streamstart,streamend);
             }
         else {
             LOGGER("GLU: ind=%d  %s streamstart=%d\n",ind, showsensorname().data(),getinfo()->update[ind].streamstart);
@@ -2461,8 +2461,11 @@ bool hasData(uint32_t nu) const {
     }
 //         return ((isAccuChek()&&pollcount()<4000)||(isDexcom()&&pollcount()<maxdexcount))&& (nu-lastused())< youngsensorsecs
 bool hasHistory() const {
-     return isLibre()||(isDexcom()&&settings->data()->dexcomPredict)||isAir();
+     return hasRealHistory()||(isDexcom()&&settings->data()->dexcomPredict);
      };
+bool hasRealHistory() const {
+     return isLibre()||isAir();
+     }
 int getStreamIdDistance() const {
     if(isAir()||isAccuChek())
         return 5;
@@ -2477,7 +2480,6 @@ struct lastscan_t {
     };
 //#endif
 
-#include "calibrate/Calibrate.hpp"
 struct HistoryIterator 
 {
     using iterator_category = std::random_access_iterator_tag;
