@@ -47,6 +47,7 @@
 #include "crypt.h"
 #include "makerandom.hpp"
 #include "myfdsan.h"
+#include "TCPConnect.hpp"
 #define lerrortag(...) lerror("sender: " __VA_ARGS__)
 #define LOGGERTAG(...) LOGGER("sender: " __VA_ARGS__)
 #define LOGARTAG(...) LOGAR("sender: " __VA_ARGS__)
@@ -56,19 +57,19 @@
 using namespace std;
 #include "mirrorerror.h"
 
-void   sendpassinit(int sock,passhost_t *host,crypt_t *ctx) {
+void   Connect::sendpassinit(passhost_t *host,crypt_t *ctx) {
    constexpr int makelen=8;
    uint8_t nonce[ASCON_AEAD_NONCE_LEN];
    constexpr int takelen=ASCON_AEAD_NONCE_LEN-makelen;
    uint8_t *takestart=nonce+makelen;
        makerandom(nonce, makelen);
-   if(int didsend=sendni(sock,nonce,makelen);didsend!=makelen) {
-      flerrortag("sendpassinit send sock=%d ret=%d\n",sock,didsend);
+   if(int didsend=s_sendni(nonce,makelen);didsend!=makelen) {
+      flerrortag("sendpassinit send getSenderIdent()=%d ret=%d\n",getSenderIdent(),didsend);
       return;
       }
-   int len=recvni(sock,takestart,takelen);
+   int len=s_recvni(takestart,takelen);
    if(len!=takelen) {
-      flerrortag("sendpassinit sock=%d recv len=%d\n",sock,len);
+      flerrortag("sendpassinit getSenderIdent()=%d recv len=%d\n",getSenderIdent(),len);
       return;
       }
         ascon_aead128a_init(ctx, host->pass.data(),nonce);   
@@ -117,10 +118,10 @@ static auto getsendmagic() {
 std::array<unsigned char,sizeof(sendmagic)>  sendmagicspec=getsendmagic();
 
 
-static int testsendmagic(passhost_t *pass,int sock) {
+ int Connect::testsendmagic(passhost_t *pass) {
    #include "receivemagic.h"
    decltype(sendmagicspec) *magicptr;
-
+   LOGARTAG("testsendmagic");
    if(pass->receivedatafrom()&&pass->newconnection) {
       magicptr=(decltype(sendmagicspec) *)alloca(sizeof(sendmagicspec));
       *magicptr=sendmagicspec;   
@@ -129,39 +130,37 @@ static int testsendmagic(passhost_t *pass,int sock) {
       }
    else
       magicptr=&sendmagicspec;
-   if(sendni(sock,magicptr->data(),magicptr->size())!=magicptr->size()) {
+   if(s_sendni(magicptr->data(),magicptr->size())!=magicptr->size()) {
       char *buf=getmirrorerror(pass);
       int waser=errno;
-      constexpr const char mess[]="send magic failed: ";
+      constexpr const char mess[]="testsendmagic: send magic failed: ";
       constexpr const int len=sizeof(mess)-1;
       memcpy(buf,mess,len);
       strerror_r(waser, buf+len, maxmirrortext-len);
       LOGGERTAG("%s\n",buf);
       return 1;
       }
-constexpr const int recsize=sizeof(receivemagic);
+   constexpr const int recsize=sizeof(receivemagic);
    char buf[recsize];
-   LOGARTAG("before recv magic");
+   LOGARTAG("testsendmagic before recv magic");
    int gotlen;
-   if((gotlen=recvni(sock,buf,recsize))!=recsize) {
+   if((gotlen=s_recvni(buf,recsize))!=recsize) {
       char *ptr=getmirrorerror(pass);
       int waser=errno;
-      int len=snprintf(ptr,maxmirrortext,"magic recv()=%d!=%d: ",gotlen,(int)recsize);
+      int len=snprintf(ptr,maxmirrortext,"testsendmagic: magic recv()=%d!=%d: ",gotlen,(int)recsize);
       strerror_r(waser, ptr+len, maxmirrortext-len);
       LOGGERTAG("%s\n",ptr);
       return 2;
       }
-   LOGARTAG("after recv magic");
+   LOGARTAG("testsendmagic: after recv magic");
    if(memcmp(buf,receivemagic,recsize-4)) {//4 less for version info
-      char wrong[]="Wrong magic";
+      char wrong[]="testsendmagic: Wrong magic";
       char *buf=getmirrorerror(pass);
       memcpy(buf,wrong,sizeof(wrong));
       LOGGERN(wrong,sizeof(wrong)-1);
       return 3;
       }
-   LOGGERTAG("testsendmagic %d success\n",sock);
-//extern void   setreceiverversion(uint8_t version) ;
-//   setreceiverversion(buf[recsize-1]);
+   LOGGERTAG("testsendmagic %d success\n",getSenderIdent());
    if(!buf[recsize-1]) {
       extern void resethost(passhost_t &host) ;
       resethost(*pass);
@@ -194,7 +193,7 @@ void sendtimeout(int sock,int secs) {
    flerrortag("getsockopt(%d,TCP_USER_TIMEOUT, ) failed",sock);
       }
  else {
-     LOGGER("USER_TIMEOUT=%d\n",retalive);
+     LOGGERTAG("USER_TIMEOUT=%d\n",retalive);
      }
 
 
@@ -202,38 +201,40 @@ void sendtimeout(int sock,int secs) {
 //extern void getmyname(int sock) ;
 
 
-bool sendtype(int sock,char type) {
-   LOGGERTAG("sendtype(%d,%d)\n",sock,type);
+bool Connect::sendtype(char type) {
+   LOGGERTAG("sendtype(%d,%d)\n",getSenderIdent(),type);
    char ant=type;
-   if(sendni(sock,&ant,1)!=1) {
+   if(s_sendni(&ant,1)!=1) {
       return false;
       }
    return true;
-        }
+   }
 
 
 extern char *getmirrorerror(const passhost_t *pass);
-
-static int shakehands(passhost_t *pass,int &sock,char stype) {
-   LOGGERTAG("shakehands connection %d\n",sock);
+void settimeouts(int sock) {
    struct timeval tv;
    tv.tv_usec = 0;
    tv.tv_sec = 60*3;
    setsockopt(sock, SOL_SOCKET, SO_RCVTIMEO, (const char*)&tv, sizeof tv);
    setsockopt(sock, SOL_SOCKET, SO_SNDTIMEO , (const char*)&tv, sizeof tv);
+   }
+
+ int Connect::shakehands(passhost_t *pass,char stype) {
+   LOGGERTAG("shakehands connection %d\n",getSenderIdent());
    if(pass->hasname) {
       const char *name= pass->getname();
-      LOGGERTAG("sendni(%d,%s,)\n",sock,name);
-      if(sendni(sock,name,pass->maxnamelen)!=pass->maxnamelen) {
-         char err[]="send name";
+      LOGGERTAG("sendni(%d,%s,)\n",getSenderIdent(),name);
+      if(s_sendni(name,pass->maxnamelen)!=pass->maxnamelen) {
+         char err[]="s_sendni name error";
          saveerror(pass,err);
-         LOGGER("%s",getmirrorerror(pass));
+         LOGGERTAG("%s\n",getmirrorerror(pass));
          return -1;
          }
       
       }
    int magret;
-   if((magret=testsendmagic(pass,sock)))  {
+   if((magret=testsendmagic(pass)))  {
       if(magret==2)  {
          if(pass->hasname) {
             savemessage(pass,"Sender with label %s rejected by receiver",pass->getname());
@@ -243,11 +244,11 @@ static int shakehands(passhost_t *pass,int &sock,char stype) {
       return -1;
       }
    if(stype) {
-      sendtype(sock,stype);
+      sendtype(stype);
       }
       
-   LOGGERTAG("sock=%d\n",sock);
-   return sock;
+   LOGGERTAG("getSenderIdent()=%d\n",getSenderIdent());
+   return 1;
    }
 /*
 sockaddr myname;
@@ -266,7 +267,7 @@ void getmyname(int sock) {
    } 
    */
 
-static int connectone( const struct sockaddr_in6  *sin, int &sock,char stype,passhost_t *pass,struct pollfd    *cons,int&use
+int TCPConnect::connectone( const struct sockaddr_in6  *sin, int &sock,char stype,passhost_t *pass,struct pollfd    *cons,int&use
 #if defined(WEAROS_MESSAGES)
       ,bool &activate
 #endif
@@ -301,12 +302,13 @@ static int connectone( const struct sockaddr_in6  *sin, int &sock,char stype,pas
 #endif
       block(so);
       sock=so;
-      if(int ret=shakehands(pass,sock,stype);ret>=0) {
+      settimeouts(sock);
+      if(shakehands(pass,stype)>=0) {
          LOGGERTAG("before poll %d\n",sock);
          for(int w=0;w<use;w++) {
             sockclose(cons[w].fd);
             }
-         return ret;
+         return sock;
          }
       sockclose(so);
       sock=-1;
@@ -315,7 +317,7 @@ static int connectone( const struct sockaddr_in6  *sin, int &sock,char stype,pas
    return -1;
    }
 
-static int makeconnection2(passhost_t *pass,int &sock,char stype) {
+int TCPConnect::makeconnection2(passhost_t *pass,char stype) {
 #ifdef WEAROS_MESSAGES
 destruct dest([pass]() {
    if(pass->wearos) {
@@ -328,9 +330,8 @@ dest.active=false;
 bool activate=true;
 #endif
    int use=0;
-
-   sock=-1;
-
+    closeSenderConnection(); 
+    int   &sock=getSenderSock();
    struct pollfd    cons[10];
    if(pass->hashostname()) { 
              struct addrinfo hints{.ai_flags=AI_ADDRCONFIG,.ai_family=AF_UNSPEC,.ai_socktype=SOCK_STREAM};
@@ -435,7 +436,7 @@ bool activate=true;
             savemessage(pass,"poll timeout");
             #ifndef NOLOG
             char *ptr=getmirrorerror(pass);
-            LOGGERTAG("%s",ptr);
+            LOGGERTAG("%s\n",ptr);
             #endif
             return -1;
             }
@@ -490,8 +491,9 @@ bool activate=true;
          if(cons[i].revents & POLLOUT){
             sock=cons[i].fd;
             block(sock);
+            settimeouts(sock);
             int ret;
-            if((ret=shakehands(pass,sock,stype))>=0) {
+            if((ret=shakehands(pass,stype))>=0) {
                for(int w=0;w<newuse;w++) {
                   sockclose(cons[w].fd);
                   }
@@ -502,7 +504,7 @@ bool activate=true;
 #ifdef WEAROS_MESSAGES
                dest.active=false;
 #endif
-               return ret;   
+               return sock;   
                }
             int so=sock;
             sock=-1;
@@ -527,13 +529,13 @@ bool activate=true;
    return -1;
    }
 
-int makeconnection(passhost_t *pass,int &sock,crypt_t*ctx,char stype) {
-   int res=makeconnection2(pass,sock,stype);
+int Connect::makeconnection(passhost_t *pass,crypt_t*ctx,char stype) {
+   int res=makeconnection2(pass,stype);
    if(res>=0) {
       const auto tag=get_owner_tag(res);
       *getmirrorerror(pass)='\0';
       if(ctx)
-         sendpassinit(sock,pass,ctx);
+         sendpassinit(pass,ctx);
       }
    return res;
    }
